/* economic.do
**
** Estimate the models with the continuous dependent variables.
**
** Copyright (c) 1999-2004 Branislav L. Slantchev (slantchev@ucsd.edu)
**
** Perform main statistical analysis for the Post-Communist Transitions Project.
**
** Permission is granted to use and modify this file provided changes and their
** authorship are correctly documented. Permission is also granted to distribute
** this file or its modified version if it is necessary for the replication of
** a different study. It is required that the new version acknowledges the use of
** this program with a brief note displayed prominently at the top.
*/
#delimit ;
version 6.0;

program drop _all;

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using economic, replace;
*log on;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use ../data/data, clear;
tsset code year;

/*
** Inflation rate analysis
*/
xtpcse cpiln cpiln_lg `model1', pair;
xtpcse cpiln cpiln_lg `model2', pair;
xtpcse cpiln cpiln_lg `model3', pair;
interact tenure tenaut, cond(auth) val(-10);
interact tenure tenaut, cond(auth) val(0);
interact tenure tenaut, cond(auth) val(9);
interact unemp unempaut, cond(auth) val(-10);
interact unemp unempaut, cond(auth) val(0);
interact unemp unempaut, cond(auth) val(9);
xtpcse cpiln cpiln_lg `model4', pair;
interact tenure tenaut, cond(auth) val(-10);
interact tenure tenaut, cond(auth) val(0);
interact tenure tenaut, cond(auth) val(9);
interact unemp unempaut, cond(auth) val(-10);
interact unemp unempaut, cond(auth) val(0);
interact unemp unempaut, cond(auth) val(9);

/*
** Economic growth analysis
*/
xtpcse gdpdiff gdpd_lg `model1', pair;
xtpcse gdpdiff gdpd_lg `model2', pair;
xtpcse gdpdiff gdpd_lg `model3', pair;
interact tenure tenaut, cond(auth) val(-10);
interact tenure tenaut, cond(auth) val(0);
interact tenure tenaut, cond(auth) val(9);
interact unemp unempaut, cond(auth) val(-10);
interact unemp unempaut, cond(auth) val(0);
interact unemp unempaut, cond(auth) val(9);
xtpcse gdpdiff gdpd_lg `model4', pair;
interact tenure tenaut, cond(auth) val(-10);
interact tenure tenaut, cond(auth) val(0);
interact tenure tenaut, cond(auth) val(9);
interact unemp unempaut, cond(auth) val(-10);
interact unemp unempaut, cond(auth) val(0);
interact unemp unempaut, cond(auth) val(9);

log close;
