*! version 1.2.1  June 1, 1999  Michael Tomz
* Estimate model and simulate parameters
* Works with regress, logit, probit, ologit, oprobit, mlogit, poisson, nbreg
* Inputs:  estimation command
*          Number of simulations (optional)
*          Stub-name for variables to generate (optional)
* Outputs: standard outputs associated with the estimation command, plus...
*          simulated parameters
*          mrt_simn, a global containing names of simulated variables
*          S_E_cmd, a global containing name of estimated model plus "simp"
*          S_E_rhs, a global containing names of right-hand-side variables
*          S_E_off, a global containing exposure for poisson/nbreg models
*          S_E_if, a global containing the "if" expression (if specified)
*          S_E_in, a global containing the "in" range (if specified)
*          S_E_wgt, a global containing the weight type (if specified)
*          S_E_exp, a global containing the weight expression (if specified)
program define estsimp
version 6.0

   parse "`*'", parse(" ")

   * Unabbreviate command name and set options
   if substr("`1'",1,3) == "reg" { local cmdname "regress" }
   else if substr("`1'",1,4) == "logi" {
      local cmdname "logit"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) NOCONSTant *"
   }
   else if substr("`1'",1,4) == "prob" {
      local cmdname "probit"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) NOCONSTant *"
   }
   else if substr("`1'",1,4) == "olog" {
      local cmdname "ologit"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) *"
   }
   else if substr("`1'",1,5) == "oprob" {
      local cmdname "oprobit"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) *"
   }
   else if substr("`1'",1,4) == "mlog" {
      local cmdname "mlogit"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) NOCOnstant *"
   }
   else if "`1'" == "poisson" {
      local cmdname "poisson"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) *"
   }
   else if "`1'" == "nbreg" {
      local cmdname "nbreg"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) *"
   }
   else if "`1'" == "xtpcse" {
      local cmdname "xtpcse"
      local usesimp "yes"
      local options "SIMS(int 1000) GENNAME(str) *"
   }

   if "`usesimp'" == "yes" {
      mac shift
      local varlist "req ex"
      local if "opt"
      local in "opt"
      local weight "fweight aweight pweight"
      parse "`*'"
      parse "`varlist'", parse(" ")
      local depvar "`1'"
      mac shift
      local rhsvars "`*'"                     /* names of explanatory vars*/
      local nrhs : word count `rhsvars'       /* numbr of explanatory vars*/
      if "`weight'" ~= "" { local wt "[`weight'`exp']" }
      * confirm variables to generate.  nptosim = # params to simulate
      if "`cmdname'" == "logit" | "`cmdname'" == "probit" {
         if "`noconst'" == "" { local nptosim = `nrhs' + 1 }
         else { local nptosim = `nrhs' }
      }
      else if "`cmdname'" == "ologit" | "`cmdname'" == "oprobit" {
         qui tab `depvar' `if' `in' `wgt'
         local nptosim = _result(2) - 1 + `nrhs'
      }
      else if "`cmdname'" == "mlogit" {
         qui tab `depvar' `if' `in' `wgt'
         if "`noconst'" == "" { local nptosim = (`nrhs'+1) * (_result(2)-1) }
         else { local nptosim = `nrhs' * (_result(2)-1) }
      }
      else if "`cmdname'" == "poisson" | "`cmdname'" == "nbreg" {
         local nptosim = `nrhs' + 1
      }
      else if "`cmdname'" == "xtpcse" {
         local nptosim = `nrhs' + 1
      }

      if "`genname'" == "" { local genname "b" }   /* stub-name to generate */
      else {
         local snp = string(`nptosim')
         local maxstub = 8 - length("`snp'")
         if length("`genname'") > `maxstub' {
            di in r _n "Your stub-name, `genname', is too long.  Please choose"
            di in r "a stub-name with no more than `maxstub' characters."
            exit
         }
      }
      local i = 1
      while `i' <= `nptosim' {
          capture confirm new variable `genname'`i'
          if _rc {
             di in r _n "A variable called `genname'`i' already exists."
             di in r "Delete `genname'`i' or choose a new stub-name " _c
             di in r "for the simulations."
             exit 110
          }
          local i = `i' + 1
      }
      * Estimate model and simulate parameters
      `cmdname' `varlist' `if' `in' `wt', `options' `noconst'
      _simp, sims(`sims') genname(`genname')
      global S_E_cmd = "$S_E_cmd"+"simp"
      global S_E_rhs "`rhsvars'"
      global S_E_if "`if'"
      global S_E_in "`in'"
      global S_E_wgt "`weight'"
      global S_E_exp "`exp'"
      if "$S_E_cmd"=="nbregsimp" { _getexpo ",`options'" } /*exposure time */
   }

   else if "`cmdname'" == "regress" {
      mac shift
      _regsimp `*'                                   /* call _regsimp proc */
   }
   else if "`1'" == "fit" {
      di in r _n "-estsimp- works with -regress-, rather than -fit-"
      exit
   }
   else if "`1'" == "by" {
      di in r _n "-estsimp- does not support the " in w "by " in r "option"
      exit
   }
   else if "`1'" == "" {
      di in r _n "Must provide model name and variable list"
      exit
   }
   else {
      di in r _n "-estsimp- does not support the " in w "`1'" in r " model"
      exit
   }

end


******************************** _simp **************************************

*! version 1.2  September 16, 1998  Michael Tomz
* Simulates parameters after a model has been estimated
* Inputs:  (optional) number of simulations
*          (optional) stub-name for variables to generate
* Reads:   S_E_cmd, a global containing name of last estimation command
*          _b, a matrix containing the parameter estimates
*          VCE, the variance-covariance matrix of estimates
* Outputs: simulated parameters
*          mrt_simn, a global containing names of simulated variables
program define _simp
version 5.0
   local options "SIMS(int 1000) GENNAME(str)"
   parse "`*'"
 * RETRIEVE ESTIMATES
   tempname pests V A row t
   matrix `pests' = get(_b)                        /* parameter estimates   */
   matrix `V' = get(VCE)                           /* variance matrix       */
 * FLATTEN PARAMETER MATRIX IF NECESSARY
   local rpests = rowsof(`pests')
   if `rpests' > 1 {
      tempname eqrow newpest
      local i = 1
      while `i' <= `rpests' {
         matrix `eqrow' = `pests'[`i',.]
         matrix `newpest' = `newpest',`eqrow'
         local i = `i' + 1
      }
      matrix `pests' = `newpest'
   }
 * SET NUMBER OF SIMULATIONS
   di _n "Simulating.  Please wait" _c
   if `sims' < 1 {
       local simsmsg "Note: You entered an invalid number of simulations."
       local simsmsg "`simsmsg'  Value changed to 1000."
       local sims = 1000
   }
   if `sims' > _N { qui set obs `sims' }
 * GENERATE `NPTOSIM' STD NORMAL RV'S, COLLECT THEIR NAMES
   local nptosim = colsof(`V')                     /* # params to simulate  */
   local i = 1
   while `i' <= `nptosim' {
       di "." _c
       tempvar c`i'
       qui gen `c`i'' = invnorm(uniform()) in 1/`sims'
       local cnames `cnames' `c`i''                /* names of std norm rv's*/
       local i = `i' + 1
   }
 * SIMULATE AND LABEL PARAMETERS
   capt matrix `A' = cholesky(`V')            /* square root of VC matrix  */
   if _rc == 506 {                            /* If VC ~ pos definite, ... */
      tempname eye transf varianc vcd tmp
      mat `eye' = I(`nptosim')                /* identity matrix */
      mat `transf' = J(1,`nptosim',0)         /* initialize transf matrix  */
      local i = 1
      while `i' <= `nptosim' {
         scalar `varianc' = `V'[`i',`i']      /* variance of parameter `i' */
         if `varianc' ~= 0 {                  /* if has variance, add row  */
            mat `tmp' = `eye'[`i',1...]       /* of `eye' to transf matrix */
            mat `transf' = `transf' \ `tmp'
         }
         local i = `i' + 1
      }
      mat `transf' = `transf'[2...,1...]      /* drop 1st row of transf mat*/
      mat `vcd' = `transf'*`V'                /* decomposed VC matrix (has */
      mat `vcd' = `vcd'*`transf''             /*   no all-zero rows)       */
      mat `A' = cholesky(`vcd')               /* square root of decomp VC  */
      mat `A' = `transf''*`A'
      mat `A' = `A'*`transf'                  /* rebuild full sq root mat  */
   }
   else if _rc { matrix `A' = cholesky(`V') } /* redisplay error message   */
   matrix colnames `A' = `cnames'    /* rename cols to `c1'..`c1`nptosim'' */
   local apnames : colnames(`V')     /* all parameter names (some repeated)*/
   local eqnames : coleq(`V')        /* all equation names (some repeated) */
   parse "`eqnames'", parse(" ")
   if "`1'" ~= "_" { local haseqnm "yes" }           /* has equation names */
   di _n "% of simulations completed: " _c
   local i = 1
   while `i' <= `nptosim' {
       di int(`i'*100/`nptosim') "% " _c
       matrix `row' = `A'[`i',.]                     /* get i^th row of A  */
       matrix score `genname'`i' = `row'             /* c(NxK) * row(1xK)' */
       qui replace `genname'`i' = `genname'`i' + `pests'[1,`i']  /*add mean*/
       local pname : word `i' of `apnames'           /* name of parameter  */
       if "`haseqnm'" == "yes" {                     /* if has equatn names*/
          matrix `t' = `V'[`i',1]                    /* get name of equatn */
          local eqname : roweq(`t')
          label var `genname'`i' "Simd `eqname':`pname' parameter"
       }
       else { label var `genname'`i' "Simd `pname' parameter" }
       local newvars "`newvars' `genname'`i'"        /* collect names      */
       local i = `i' + 1
   }
 * OUTPUT MESSAGES
   di
   if "`simsmsg'" != "" { di in r "`simsmsg'" }
   di _n "Number of simulations  : `sims'"
   di "Names of new variables :`newvars'"
 * SAVE GLOBALS
   global mrt_simn "`newvars'"
end


******************************* _regsimp *************************************

*! version 1.2  September 16, 1998  Michael Tomz
* Run linear regression and simulate parameters
program define _regsimp
version 5.0
 * PARSE INPUTS
   local varlist "req ex"
   local if "opt"
   local in "opt"
   local weight "aweight fweight pweight"
   #delimit ;
   local options "SIMS(int 1000) GENNAME(str) NOConstant
      Hascons CLuster(str) Robust HC2 HC3 MSe1";
   #delimit cr
   local options "`options' *"
   parse "`*'"
   if "`mse1'" ~= "" {
      di in r _n "mse1 option not allowed with -estsimp-"
      exit
   }
   parse "`varlist'", parse(" ")
   mac shift
   local rhsvars "`*'"
 * CONFIRM VARIABLES TO GENERATE, CHECK FOR CONSTANT
   local k : word count `rhsvars'
   if "`noconst'" == "" & "`hascons'" == "" {
      local k = `k' + 1           /* # explanatory vars including constant */
      local ksig = `k' + 1        /* # explanatory vars plus sigma */
   }
   else { local ksig = `k' + 1 }
   if "`genname'" == "" { local genname "b" }
   else {
      local snp = string(`ksig')
      local maxstub = 8 - length("`snp'")
      if length("`genname'") > `maxstub' {
         di in r _n "Your stub-name, `genname', is too long.  Please choose"
         di in r "a stub-name with no more than `maxstub' characters."
         exit
      }
   }
   local i = 1
   while `i' <= `ksig' {
      capture confirm new variable `genname'`i'
      if _rc {
         di in r _n "A variable called `genname'`i' already exists."
         di in r "Delete `genname'`i' or choose a new stub-name " _c
         di in r "for the simulations."
         exit 110
      }
      local newvars "`newvars' `genname'`i'"
      local i = `i' + 1
   }
 * ESTIMATE MODEL AND RETREIVE ESTIMATES
   if "`weight'"~="" { local wt "[`weight'`exp']" }
   if "`cluster'"~="" { local cluster "cluster(`cluster')" }
   regress `varlist' `if' `in' `wt', `options' `noconst' /*
      */ `hascons' `robust' `hc2' `hc3' `cluster'
   tempname pests V A row
   matrix `pests' = get(_b)
   matrix `V' = get(VCE)
 * ADJUST FOR PROBLEMS WITH CONSTANT AND VAR-COVAR MATRIX
   if "`hascons'" ~= "" {
      if _b[_cons] == 0 & _se[_cons] == 0 {
         matrix `pests' = `pests'[1,1..`k']       /* drop _cons from vector */
         matrix `V' = `V'[1..`k',1..`k']          /* drop _cons from matrix */
      }
   }
   if _result(4) ~= . & _result(5) ~= . {
      local ee = _result(4)
      local df = _result(5)
   }
   * re-run reg without special variance options to get ee,df
   else {
      qui reg `varlist' `if' `in' `wt', `options' `noconst' `hascons'
      local ee = _result(4)
      local df = _result(5)
   }
 * SET NUMBER OF SIMULATIONS
   if `sims' < 1 {
       local simsmsg "Note: You entered an invalid number of simulations."
       local simsmsg "`simsmsg'  Value changed to 1000."
       local sims = 1000
   }
   if `sims' > _N { qui set obs `sims' }
 * GENERATE `K' (NOT `KSIG') STD NORMAL RV'S, COLLECT THEIR NAMES
   di _n "Simulating.  Please wait" _c
   local i = 1
   while `i' <= `k' {
      di "." _c
      tempvar c`i'
      local cnames `cnames' `c`i''
      qui gen `c`i'' = invnorm(uniform()) in 1/`sims'
      local i = `i' + 1
   }
 * SIMULATE BETAS FROM MULTIVARIATE NORMAL
   matrix `A' = cholesky(`V')
   matrix colnames `A' = `cnames'
   local pnames : colnames(`pests')         /* get names of parameters */
   local i = 1
   while `i' <= `k' {
      matrix `row' = `A'[`i',.]
      tempvar b`i'
      matrix score `b`i'' = `row'
      qui replace `b`i'' = `b`i'' + `pests'[1,`i']
      local i = `i' + 1
   }
 * SIMULATE SIGMAS FROM SCALED INVERSE CHI-SQUARED DISTRIBUTION
   tempvar sigsim z2
   qui gen `sigsim' = .
   di _n "% of simulations completed: 0% " _c
   local i = 1
   while `i' <= `sims' {
      local percent = `i'*100/`sims'
      if int(`percent'/10)*10 == `percent' { di "`percent'% " _c }
      qui gen `z2' = invnorm(uniform())^2 in 1/`df'
      su `z2', meanonly
      local sumz2 = _result(18)
      qui replace `sigsim'=sqrt(`ee'/`sumz2') in `i'
      qui drop `z2'
      local i = `i' + 1
   }
 * SAVE SIMULATIONS TO MEMORY
   local i = 1
   while `i' <= `k' {
      qui gen `genname'`i' = `b`i''
      local pname : word `i' of `pnames'
      label var `genname'`i' "Simd `pname' parameter"
      local i = `i' + 1
   }
   qui gen `genname'`ksig' = `sigsim'
   label var `genname'`ksig' "Simulated sigma parameter"
 * OUTPUT MESSAGES
   di
   if "`simsmsg'" ~= "" { di in r "`simsmsg'" }
   di _n "Number of simulations  : `sims'"
   di "Names of new variables :`newvars'"
 * SAVE GLOBALS
   global S_E_cmd "regresssimp"
   global S_E_rhs "`rhsvars'"
   global S_E_if "`if'"
   global S_E_in "`in'"
   global S_E_wgt "`weight'"
   global S_E_exp "`exp'"
   global mrt_simn "`newvars'"
end


******************************* _getexpo *************************************

*! version 1.2  September 16, 1998  Michael Tomz
* Save exposure/offset expression (called if model is nbreg)
program define _getexpo
   local options "Exposure(string) Offset(string)"
   parse "`*'"
   if "`exposur'" ~= "" { global S_E_off "`exposur'" }
   else if "`offset'" ~= "" { global S_E_off "exp(`offset')" }
end
