/*
** Monte Carlo simulations (requires CLARIFY with xtpcse modification)
*/
#delimit ;
version 6.0;

program define _simpart;
    syntax, GOVFRAG(integer) [CONF(real $S_level)];

    loc left = (100-`conf')/2;
    loc right = 100-`left';
    tempvar exval;

    setx govfrag `govfrag';
    simqi, genev(`exval');
    qui replace `exval' = exp(`exval');
    su `exval', meanonly;
    loc themean = r(mean);
    _pctile `exval', p(`left' `right');
    loc lbound = r(r1);
    loc ubound = r(r2);

    di in gr _dup(45) "-";
    di in gr "govfrag=" %1.0f `govfrag' "|"  _col(17) "Mean"
             _col(26) "[" %2.0f `conf' "% Conf. Interval]";
    di in gr _dup(45) "-";
    loc sksp = 8-length("$S_E_depv");
    di in gr _skip(`sksp') "$S_E_depv |" in ye _col(12) %9.4g `themean'
             _col(25) %10.4g `lbound' " " %10.4g `ubound';
    di in gr _dup(45) "-";
end;

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using simpart, replace;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use data, clear;
tsset code year;

loc cnf = 90;     /* confidence level */

* do the estimations and simulations;
estsimp xtpcse cpiln cpiln_lg `model2', pair genname(bsim);
setx mean;
setx gdp87 median eutrade2 median fdi median;
_simpart, govfrag(1) conf(`cnf');
_simpart, govfrag(4) conf(`cnf');

log close;
