/* simunemp.do
**
** Copyright (c) 1999-2004 Branislav L. Slantchev (slantchev@ucsd.edu)
**
** Simulate effect of unemployment for the Post-Communist Transitions Project.
**
** Permission is granted to use and modify this file provided changes and their
** authorship are correctly documented. Permission is also granted to distribute
** this file or its modified version if it is necessary for the replication of
** a different study. It is required that the new version acknowledges the use of
** this program with a brief note displayed prominently at the top.
*/
#delimit;
version 6.0;

program drop _all;

/****************************************************************************/
program define _simunem;
    syntax , UNEMP(real) AUTH(real) TENURE(real)
            [INTERACT UNPACK CONF(real $S_level)];

    tempvar exvar;

    loc left = (100-`conf')/2;
    loc right = 100-`left';

    loc isint = cond("`interac'"=="","no","yes");

    setx auth `auth' tenure `tenure' unemp `unemp';
    if "`isint'" == "yes" {;
        setx tenaut `tenure'*`auth' unempaut `unemp'*`auth';
    };

    simqi, listx genev(`exvar');
    if "`unpack'" ~= "" {;
        qui replace `exvar' = exp(`exvar');
    };

    su `exvar', meanonly;
    loc themean = r(mean);
    _pctile `exvar', p(`left' `right');
    loc lbound = r(r1);
    loc ubound = r(r2);

    di in gr _dup(45) "-";
    di in gr "   unemp |" _col(12) %9.4g `unemp';
    di in gr "    auth |" _col(12) %9.4g `auth';
    di in gr "interact |" _col(12) "`isint'";
    di in gr _dup(45) "-";
    di in gr _col(10) "|"  _col(17) "Mean"
             _col(26) "[" %2.0f `conf' "% Conf. Interval]";
    di in gr _dup(45) "-";
    loc sksp = 8-length("$S_E_depv");
    di in gr _skip(`sksp') "$S_E_depv |" in ye _col(12) %9.4g `themean'
             _col(25) %10.4g `lbound' " " %10.4g `ubound';
    di in gr _dup(45) "-";
end;

/****************************************************************************/

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using simunemp, replace;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use ../data/data, clear;
tsset code year;

loc cnf = 95;
loc minun = 4;      /* min/max values to use for unemployment */
loc maxun = 20;

qui sum auth;
loc minauth = r(min);
loc maxauth = r(max);
loc medauth = 0;
_pctile tenure, p(50);
loc tenure = r(r1);

estsimp xtpcse cpiln cpiln_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

_simunem, unpack unemp(`minun') auth(`minauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unpack unemp(`maxun') auth(`minauth') tenure(`tenure')
          interact conf(`cnf');

_simunem, unpack unemp(`minun') auth(`medauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unpack unemp(`maxun') auth(`medauth') tenure(`tenure')
          interact conf(`cnf');

_simunem, unpack unemp(`minun') auth(`maxauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unpack unemp(`maxun') auth(`maxauth') tenure(`tenure')
          interact conf(`cnf');

drop bsim*;

estsimp xtpcse gdpdiff gdpd_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

_simunem, unemp(`minun') auth(`minauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unemp(`maxun') auth(`minauth') tenure(`tenure')
          interact conf(`cnf');

_simunem, unemp(`minun') auth(`medauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unemp(`maxun') auth(`medauth') tenure(`tenure')
          interact conf(`cnf');

_simunem, unemp(`minun') auth(`maxauth') tenure(`tenure')
          interact conf(`cnf');
_simunem, unemp(`maxun') auth(`maxauth') tenure(`tenure')
          interact conf(`cnf');

log close;
